@@ -1,14 +1,16 @@
-import sys
 from bruhanimate.bruhscreen import Screen
-from bruhanimate.bruheffects    import BaseEffect, StaticEffect, OffsetEffect, NoiseEffect, StarEffect, PlasmaEffect, GameOfLifeEffect, RainEffect
+from bruhanimate.bruheffects    import BaseEffect, StaticEffect, OffsetEffect, NoiseEffect, StarEffect, PlasmaEffect, GameOfLifeEffect, RainEffect, MatrixEffect, _LINE, DrawLines
 from bruhanimate.bruhffer       import Buffer
-from bruhanimate.bruhrenderer   import BaseRenderer, EffectRenderer, CenterRenderer, PanRenderer
+from bruhanimate.bruhrenderer   import BaseRenderer, EffectRenderer, CenterRenderer, PanRenderer, FocusRenderer
 from bruhanimate import images
-import demo
+from demos import demo, line_demo
+
+
 
 __all__ = [
     "Screen",
     "demo"
+    "line_demo"
     "BaseEffect",
     "StaticEffect",
     "OffsetEffect", 
@@ -17,10 +19,14 @@ __all__ = [
     "PlasmaEffect",
     "GameOfLifeEffect",
     "RainEffect",
+    "MatrixEffect",
+    "DrawLines",
+    "_LINE",
     "Buffer",
     "BaseRenderer",
     "EffectRenderer",
     "CenterRenderer",
     "PanRenderer",
+    "FocusRenderer",
     "images"
 ]
\ No newline at end of file
